@@ -21,13 +21,22 @@ configure_calamares(){
             msg2 "Configuring: Calamares %s" "$config"
 
             if [[ -f "$mods"/services-artix.conf ]]; then
-                local svc
+                local svc usvc
                 svc=$(yaml_array "${SERVICES[@]}") \
                     yq -P 'with(.;
                             .command = "artix-service" |
                             .services = env(svc) )' \
                         -i "$mods"/services-artix.conf
             fi
+            if [[ -f "$mods"/postcfg.conf ]]; then
+                local  usvc initsys
+                initsys="${INITSYS}" \
+                usvc=$(yaml_array "${USER_SERVICES[@]}") \
+                    yq -P 'with(.;
+                            .initsys = env(initsys) |
+                            .user-services = env(usvc) )' \
+                        -i "$mods"/postcfg.conf
+            fi
         fi
     done
     if [[ -d "$1"/etc/calamares-offline ]]; then
